===================
django-simpleimages
===================

This opinionated Django utility will take the image file from one
:py:class:`~django.db.models.ImageField` and transform it onto
another field, when the model saves.

.. toctree::
   :maxdepth: 4

   why
   configuration
   usage
   contributing
   changelog
   reference/index
